@@ -13,11 +13,11 @@ PGObject::Simple::Role - Moo/Moose mappers for minimalist PGObject framework
 
 =head1 VERSION
 
-Version 1.13.1
+Version 1.01
 
 =cut
 
-our $VERSION = '1.13.1';
+our $VERSION = '1.01';
 
 
 =head1 SYNOPSIS
@@ -169,7 +169,10 @@ sub _get_dbh {
 
 =head2 call_procedure
 
-Identical to PGObject::Simple::call_procedure
+Identical interface to PGObject::Simple->call_procedure.
+
+This can be used on objects or on the packages themselves.  I.e.  
+mypackage->call_procedure() and $myobject->call_procedure() both work.
 
 =cut
 
@@ -191,11 +194,6 @@ sub call_procedure {
                  unless defined $args{funcschema} or ref $self;
     }
     my @rows = $obj->call_procedure(%args);
-    for my $row (@rows){
-        for (keys %$row){
-            delete $row->{$_} unless defined $row->{$_};
-        }
-    }
     return @rows if wantarray;
     return shift @rows;
 }
@@ -229,16 +227,21 @@ sub call_dbmethod {
     my $info = PGObject->function_info(%args);
 
     my $dbargs = [];
-    @$dbargs = map {
-        my $argname = $_->{name};
+    for my $arg (@{$info->{args}}){
+        $arg->{name} =~ s/^in_//;
         my $db_arg;
-        $argname =~ s/^in_//;
-        local $@;
-        eval { $db_arg = $self->can($argname)->($self) }
-            if ref $self and $argname;
-        $db_arg = $args{args}->{$argname} if exists $args{args}->{$argname};
-        $db_arg;
-    } @{$info->{args}};
+        eval { $db_arg = $self->can($arg->{name})->($self) } if ref $self;
+        if ($args{args}->{$arg->{name}}){
+            $db_arg = $args{args}->{$arg->{name}};
+        }
+        if (eval {$db_arg->can('to_db')}){
+           $db_arg = $db_arg->to_db;
+        }
+        if ($arg->{type} eq 'bytea'){
+           $db_arg = { type => 'bytea', value => $db_arg};
+        }
+        push @$dbargs, $db_arg;
+    }
     $args{args} = $dbargs;
     my @rows;
     if (ref $self){
@@ -277,12 +280,6 @@ Chris Travers,, C<< <chris.travers at gmail.com> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-pgobject-simple-role at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=PGObject-Simple-Role>.  I will be notified, and then you'll
-Chris Travers,, C<< <chris.travers at gmail.com> >>
-
-=head1 BUGS
-
 Please report any bugs or feature requests to C<bug-pgobject-simple-role at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=PGObject-Simple-Role>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
@@ -325,7 +322,7 @@ L<http://search.cpan.org/dist/PGObject-Simple-Role/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2013-2014 Chris Travers,.
+Copyright 2013 Chris Travers,.
 
 Redistribution and use in source and compiled forms with or without 
 modification, are permitted provided that the following conditions are met:
